@@ -250,11 +250,7 @@ class Tree:
             self.root.edge_length = None
 
     def deroot(self):
-        '''If tree bifurcates at the root, contract an edge incident with the root to create a trifurcation at the root.
-
-        Args:
-            ``label`` (``str``): The desired label of the new child
-        '''
+        '''If tree bifurcates at the root, contract an edge incident with the root to create a trifurcation at the root.'''
         if self.root.num_children() != 2:
             raise RuntimeError("Can only deroot a tree with degree-2 node at the root")
         children = self.root.child_nodes()
@@ -577,6 +573,10 @@ class Tree:
             for a in node.traverse_ancestors(include_self=False):
                 keep.add(a)
         out = Tree(); out.root.label = self.root.label; out.root.edge_length = self.root.edge_length
+        if hasattr(self.root, 'node_params'):
+            out.root.node_params = self.root.node_params
+        if hasattr(self.root, 'edge_params'):
+            out.root.edge_params = self.root.edge_params
         q_old = deque(); q_old.append(self.root)
         q_new = deque(); q_new.append(out.root)
         while len(q_old) != 0:
@@ -584,6 +584,10 @@ class Tree:
             for c_old in n_old.children:
                 if c_old in keep:
                     c_new = Node(label=str(c_old), edge_length=c_old.edge_length); n_new.add_child(c_new)
+                    if hasattr(c_old, 'node_params'):
+                        c_new.node_params = c_old.node_params
+                    if hasattr(c_old, 'edge_params'):
+                        c_new.edge_params = c_old.edge_params
                     q_old.append(c_old); q_new.append(c_new)
         if suppress_unifurcations:
             out.suppress_unifurcations()
@@ -606,7 +610,7 @@ class Tree:
         '''Extract a copy of this ``Tree`` with only the leaves labeled by the strings in ``labels``
 
         Args:
-            ``leaves`` (``set``): Set of leaf labels to include.
+            ``labels`` (``set``): Set of leaf labels to include.
 
             ``suppress_unifurcations`` (``bool``): ``True`` to suppress unifurcations, otherwise ``False``
 
@@ -896,6 +900,14 @@ class Tree:
         else:
             return f'{self.root.newick()}{suffix}'
 
+    def num_cherries(self):
+        '''Returns the number of cherries (i.e., internal nodes that only have leaf children) in this ``Tree``
+
+        Returns:
+            ``int``: The number of cherries in this ``Tree``
+        '''
+        return sum(sum(not child.is_leaf() for child in node.children) == 0 for node in self.traverse_internal())
+
     def num_lineages_at(self, distance):
         '''Returns the number of lineages of this ``Tree`` that exist ``distance`` away from the root
 
@@ -1379,9 +1391,16 @@ def read_tree_newick(newick):
         f = open(expanduser(newick)); ts = f.read().strip(); f.close()
     else:
         ts = newick.strip()
-    lines = ts.splitlines()
+    lines = [l.strip() for l in ts.splitlines()]
     if len(lines) != 1:
-        return [read_tree_newick(l) for l in lines]
+        is_multi_newick = True
+        for l in lines:
+            if not l.endswith(';'):
+                is_multi_newick = False
+        if is_multi_newick:
+            return [read_tree_newick(l) for l in lines]
+        else:
+            ts = ts.replace('\n','')
     try:
         t = Tree(); t.is_rooted = ts.startswith('[&R]')
         if ts[0] == '[':
